@@ -73,9 +73,22 @@ class File:
     def read(self):
         """Returns existing file content"""
 
+
         if self.encode != None:
-            t = f.read().decode(self.encode)
+            # t = f.read().decode(self.encode)
             f = open(self.fileName, "rb")
+            t = f.read()
+
+            # with open(self.fileName, "rb") as binary_file:
+            #     # Read the whole file at once
+            #     f = binary_file.read()
+
+
+            # with open(self.fileName, "rb") as f:
+            #     byte = f.read(1)
+            #         while byte:
+            #         # Do stuff with byte.
+            #         byte = f.read(1)
         else:
             f = open(self.fileName)
             t = f.read()
